Given<T extends FlutterTestHarness> class
base
Given class used to setup the test.
- Inheritance
- Implementers
- Available extensions
Constructors
- Given(T harness)
-
const
Properties
- harness → T
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tester → WidgetTester
-
Available on GWTBase<
WidgetTestHarness> , provided by the CallbackClassBaseWidgetTester extensionno setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pumpWidget(
Widget widget, {Duration? duration, EnginePhase phase = EnginePhase.sendSemanticsUpdate, bool wrapWithView = true}) → Future< void> -
Available on Given<
passthrough for WidgetTester.pumpWidgetWidgetTestHarness> , provided by the CommonGivenWidgetTestHelpers extension -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited