Then<T extends FlutterTestHarness> class
base
Then class used for asserting behavior
- Inheritance
- Implementers
- Available extensions
Constructors
- Then(T harness)
-
const
Properties
- harness → T
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tester → WidgetTester
-
Available on GWTBase<
WidgetTestHarness> , provided by the CallbackClassBaseWidgetTester extensionno setter
Methods
-
findsAtLeastNWidgets(
Finder finder, int n, {String? reason}) → void -
Available on Then<
WidgetTestHarness> , provided by the CommonThenWidgetTestHelpers extension -
findsNothing(
Finder finder, {String? reason}) → void -
Available on Then<
WidgetTestHarness> , provided by the CommonThenWidgetTestHelpers extension -
findsNWidgets(
Finder finder, int n, {String? reason}) → void -
Available on Then<
WidgetTestHarness> , provided by the CommonThenWidgetTestHelpers extension -
findsOneWidget(
Finder finder, {String? reason}) → void -
Available on Then<
WidgetTestHarness> , provided by the CommonThenWidgetTestHelpers extension -
findsWidgetWithText(
Finder finder, dynamic matcher, {String? reason}) → void -
Available on Then<
WidgetTestHarness> , provided by the CommonThenWidgetTestHelpers extension -
matchesSemanticLabel(
Finder find, String label) → void -
Available on Then<
SemanticTesterMixin> , provided by the SemanticsHandleTesterThen extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited