When<T extends FlutterTestHarness> class base

When class used for when user performs action or something happens in the system

Inheritance
Implementers
Available extensions

Constructors

When(T harness)
const

Properties

harness → T
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tester WidgetTester

Available on GWTBase<WidgetTestHarness>, provided by the CallbackClassBaseWidgetTester extension

no setter

Methods

ensureVisible(Finder finder) Future<void>

Available on When<WidgetTestHarness>, provided by the CommonWhenWidgetTestHelpers extension

passthrough for WidgetTester.ensureVisible
fling(Finder finder, Offset offset, double speed, {int? pointer, int buttons = kPrimaryButton, Duration frameInterval = const Duration(milliseconds: 16), Offset initialOffset = Offset.zero, Duration initialOffsetDelay = const Duration(seconds: 1), bool warnIfMissed = true, PointerDeviceKind deviceKind = PointerDeviceKind.touch}) Future<void>

Available on When<WidgetTestHarness>, provided by the CommonWhenWidgetTestHelpers extension

passthrough for WidgetTester.fling
idle() Future<void>

Available on When<WidgetTestHarness>, provided by the CommonWhenWidgetTestHelpers extension

passthrough for WidgetTester.idle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pump([Duration? duration, EnginePhase phase = EnginePhase.sendSemanticsUpdate]) Future<void>

Available on When<WidgetTestHarness>, provided by the CommonWhenWidgetTestHelpers extension

passthrough for WidgetTester.pump
pumpAndSettle([Duration duration = const Duration(milliseconds: 100), EnginePhase phase = EnginePhase.sendSemanticsUpdate, Duration timeout = const Duration(minutes: 10)]) Future<int>

Available on When<WidgetTestHarness>, provided by the CommonWhenWidgetTestHelpers extension

passthrough for WidgetTester.pumpAndSettle
tap(Finder finder, {int? pointer, int buttons = kPrimaryButton, bool warnIfMissed = true}) Future<void>

Available on When<WidgetTestHarness>, provided by the CommonWhenWidgetTestHelpers extension

passthrough for WidgetTester.tap
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited