Base class for UnitTestHarness and WidgetTestHarness intended for mixins to conform to build up testing feature dependencies see NetworkImageMixin for example
mixin SomeFeature on TestHarness {
}
- Implementers
Constructors
Properties
- commonTestHelper → CommonTester
-
abstraction so mixins can be written to support dart tests and widget tests
uses
pump,pumpAndSettle, andidlein widget tests. Uses Future.value and Future.microtask for unit testsno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setup(
) → Future< void> - Used so mixins can setup testing infrastructure see SemanticTesterMixin for example
-
setupWidgetTree(
Widget child) → Widget - Allows mixins to add appropriate widgets if needed.
-
setupZones(
Future< void> child()) → Future<void> - used to wrap callback with runZoned or other test helpers that take a function. see NetworkImageMixin for example of setup.
-
teardown(
) → Future< void> - Used so mixins can teardown testing infrastructure see SemanticTesterMixin for example
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited