NetworkImageMixin mixin base
mixin to provide support for loading images instead of throwing an error provides support to load arbitrary images based on the uri
- Superclass constraints
Properties
- commonTestHelper → CommonTester
-
abstraction so mixins can be written to support dart tests and widget tests
uses
pump,pumpAndSettle, andidlein widget tests. Uses Future.value and Future.microtask for unit testsno setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bytesForUrlRequest(
Uri url) → List< int> - Used to provide a value for Http requests intended for Image.network and NetworkImage Can provide custom image by reading image from disk Example:
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setup(
) → Future< void> -
Used so mixins can setup testing infrastructure see SemanticTesterMixin for example
inherited
-
setupWidgetTree(
Widget child) → Widget -
Allows mixins to add appropriate widgets if needed.
inherited
-
setupZones(
Future< void> child()) → Future<void> -
used to wrap callback with runZoned or other test helpers that take a function.
see NetworkImageMixin for example of setup.
override
-
teardown(
) → Future< void> -
Used so mixins can teardown testing infrastructure see SemanticTesterMixin for example
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited