When<T extends FlutterTestHarness> class
base
When class used for when user performs action or something happens in the system
- Inheritance
- Implementers
- Available extensions
Constructors
- When(T harness)
-
const
Properties
- harness → T
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tester → WidgetTester
-
Available on GWTBase<
WidgetTestHarness> , provided by the CallbackClassBaseWidgetTester extensionno setter
Methods
-
ensureVisible(
Finder finder) → Future< void> -
Available on When<
passthrough for WidgetTester.ensureVisibleWidgetTestHarness> , provided by the CommonWhenWidgetTestHelpers extension -
fling(
Finder finder, Offset offset, double speed, {int? pointer, int buttons = kPrimaryButton, Duration frameInterval = const Duration(milliseconds: 16), Offset initialOffset = Offset.zero, Duration initialOffsetDelay = const Duration(seconds: 1), bool warnIfMissed = true, PointerDeviceKind deviceKind = PointerDeviceKind.touch}) → Future< void> -
Available on When<
passthrough for WidgetTester.flingWidgetTestHarness> , provided by the CommonWhenWidgetTestHelpers extension -
idle(
) → Future< void> -
Available on When<
passthrough for WidgetTester.idleWidgetTestHarness> , provided by the CommonWhenWidgetTestHelpers extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pump(
[Duration? duration, EnginePhase phase = EnginePhase.sendSemanticsUpdate]) → Future< void> -
Available on When<
passthrough for WidgetTester.pumpWidgetTestHarness> , provided by the CommonWhenWidgetTestHelpers extension -
pumpAndSettle(
[Duration duration = const Duration(milliseconds: 100), EnginePhase phase = EnginePhase.sendSemanticsUpdate, Duration timeout = const Duration(minutes: 10)]) → Future< int> -
Available on When<
passthrough for WidgetTester.pumpAndSettleWidgetTestHarness> , provided by the CommonWhenWidgetTestHelpers extension -
tap(
Finder finder, {int? pointer, int buttons = kPrimaryButton, bool warnIfMissed = true}) → Future< void> -
Available on When<
passthrough for WidgetTester.tapWidgetTestHarness> , provided by the CommonWhenWidgetTestHelpers extension -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited